@@ -1,9 +1,10 @@
 import argparse
 import sys
 
-from xklb.extract import main as extract
 from xklb.fs_actions import filesystem, listen, watch
-from xklb.tube_actions import tube_add, tube_listen, tube_watch
+from xklb.fs_extract import main as extract
+from xklb.tube_actions import tube_listen, tube_watch
+from xklb.tube_extract import tube_add
 from xklb.utils import Subcommand, log
 
 
